==> haskell-network-info-0.2.0.8-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-info
version: 0.2.0.8
id: network-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
key: network-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/network-info
synopsis: Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.
    .
    network-info has been tested and is known to work on
    Ubuntu 10.10, FreeBSD 9.0, Mac OS X 10.6.4 and Windows
    XP/7. It probably works on other flavours of Linux,
    OS X, FreeBSD and Windows as well.
category: Network
author: Jacob Stanley
exposed: True
exposed-modules:
    Network.Info
abi: 955ea7c016dc8bbe6943ffdc59f9c95c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-info-0.2.0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-info-0.2.0.8
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/network-info-0.2.0.8
hs-libraries: HSnetwork-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-network-info/html/network-info.haddock
haddock-html: /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-info-0.2.0.8-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-info
version: 0.2.0.8
id: network-info-0.2.0.8-3CNHbSDxkB04OXdr5Q0x5c
key: network-info-0.2.0.8-3CNHbSDxkB04OXdr5Q0x5c
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/network-info
synopsis: Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.
    .
    network-info has been tested and is known to work on
    Ubuntu 10.10, FreeBSD 9.0, Mac OS X 10.6.4 and Windows
    XP/7. It probably works on other flavours of Linux,
    OS X, FreeBSD and Windows as well.
category: Network
author: Jacob Stanley
exposed: True
exposed-modules:
    Network.Info
abi: 97976e45065e644ca96a645b1f562d71
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/network-info-0.2.0.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/network-info-0.2.0.8
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/network-info-0.2.0.8
hs-libraries: HSnetwork-info-0.2.0.8-3CNHbSDxkB04OXdr5Q0x5c
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-network-info/html/network-info.haddock
haddock-html: /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
